﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart;
using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 축 1
        /// </summary>
        private Axis axis1;

        /// <summary>
        /// 축 2
        /// </summary>
        private Axis axis2;

        /// <summary>
        /// 축 3
        /// </summary>
        private Axis axis3;

        /// <summary>
        /// 캔들 시리즈
        /// </summary>
        private Candle candle;

        /// <summary>
        /// 볼륨 시리즈
        /// </summary>
        private Volume volume;

        /// <summary>
        /// CLV 함수
        /// </summary>
        private CLVFunction clvFunction;

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 축 1을 생성한다.

            this.axis1 = new Axis();

            this.axis1.StartPosition = 0d;
            this.axis1.EndPosition   = 37d;
            this.axis1.MaximumOffset = 5;
            this.axis1.MinimumOffset = 5;

            #endregion
            #region 축 2를 생성한다.

            this.axis2 = new Axis();

            this.axis2.StartPosition = 40d;
            this.axis2.EndPosition   = 69d;

            #endregion
            #region 축 3을 생성한다.

            this.axis3 = new Axis();
 
            this.axis3.StartPosition = 72d;
            this.axis3.EndPosition   = 100d;

            #endregion
            #region 캔들 시리즈를 생성한다.

            this.candle = new Candle();

            this.candle.Title          = "Candle";
            this.candle.VertAxis       = VerticalAxis.Custom;
            this.candle.CustomVertAxis = this.axis1;

            #endregion
            #region 볼륨 시리즈를 생성한다.

            this.volume = new Volume();

            this.volume.Title          = "Volume";
            this.volume.CustomVertAxis = this.axis2;
            this.volume.VertAxis       = VerticalAxis.Custom;
            this.volume.Brush.Color    = Color.FromArgb(119, 153, 214);

            #endregion
            #region CLV 함수를 생성한다.

            this.clvFunction = new CLVFunction();

            this.clvFunction.Accumulate = true;
            this.clvFunction.Period     = 1d;
            this.clvFunction.Volume     = this.volume;

            #endregion
            #region 라인 시리즈를 생성한다.

            this.line = new Line();

            this.line.Title          = "CLV Function";
            this.line.VertAxis       = VerticalAxis.Custom;
            this.line.CustomVertAxis = this.axis3;
            this.line.DataSource     = this.candle;
            this.line.Function       = this.clvFunction;
            this.line.Brush.Color    = Color.FromArgb(225, 207, 104);
            this.line.Color          = Color.FromArgb(255, 207, 104);

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Panel.MarginLeft  = 5;
            this.tChart.Legend.Visible    = false;
            this.tChart.Axes.Left.Visible = false;

            this.tChart.Axes.Custom.Add(this.axis1);
            this.tChart.Axes.Custom.Add(this.axis2);
            this.tChart.Axes.Custom.Add(this.axis3);

            this.tChart.Series.Add(this.candle);
            this.tChart.Series.Add(this.volume);
            this.tChart.Series.Add(this.line);

            #endregion

            this.candle.FillSampleValues();
            this.volume.FillSampleValues();

            this.accumulateCheckBox.Checked       = this.clvFunction.Accumulate;
            this.multiplyByVolumeCheckBox.Checked = this.clvFunction.Volume != null;

            this.accumulateCheckBox.Click       += accumulateCheckBox_Click;
            this.multiplyByVolumeCheckBox.Click += multiplybyVolumeCheckBox_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Accumulate 체크 박스 클릭시 처리하기 - accumulateCheckBox_Click(sender, e)

        /// <summary>
        /// Accumulate 체크 박스 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void accumulateCheckBox_Click(object sender, EventArgs e)
        {
            this.clvFunction.Accumulate = this.accumulateCheckBox.Checked;
        }

        #endregion
        #region Multiply by Volume 체크 박스 클릭시 처리하기 - multiplybyVolumeCheckBox_Click(sender, e)

        /// <summary>
        /// Multiply by Volume 체크 박스 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void multiplybyVolumeCheckBox_Click(object sender, EventArgs e)
        {
            this.clvFunction.Volume = this.multiplyByVolumeCheckBox.Checked ? this.volume : null;
        }

        #endregion
    }
}